@@ -30,10 +30,8 @@
 #include <libcaja-extension/caja-menu-provider.h>
 #include "caja-engrampa.h"
 
-
 static GObjectClass *parent_class;
 
-
 static void
 extract_to_callback (CajaMenuItem *item,
 		     gpointer          user_data)
@@ -71,7 +69,6 @@ extract_to_callback (CajaMenuItem *item,
 	g_free (quoted_default_dir);
 }
 
-
 static void
 extract_here_callback (CajaMenuItem *item,
 		       gpointer          user_data)
@@ -103,7 +100,6 @@ extract_here_callback (CajaMenuItem *item,
 	g_string_free (cmd, TRUE);
 }
 
-
 static void
 add_callback (CajaMenuItem *item,
               gpointer      user_data)
@@ -140,7 +136,6 @@ add_callback (CajaMenuItem *item,
 	g_string_free (cmd, TRUE);
 }
 
-
 static struct {
 	const char *mime_type;
 	gboolean    is_compressed;
@@ -195,21 +190,20 @@ static struct {
 		{ "application/x-zip", TRUE },
 		{ "application/x-zip-compressed", TRUE },
 		{ "application/x-zoo", TRUE },
-		{ ZSTD_MIME_TYPE, TRUE },
+		{ "application/zstd", TRUE },
+		{ "application/x-zstd", TRUE },
 		{ "application/x-zstd-compressed-tar", TRUE },
 		{ "application/zip", TRUE },
 		{ "multipart/x-zip", TRUE },
 		{ NULL, FALSE }
 };
 
-
 typedef struct {
       gboolean is_archive;
       gboolean is_derived_archive;
       gboolean is_compressed_archive;
 } FileMimeInfo;
 
-
 static FileMimeInfo
 get_file_mime_info (CajaFileInfo *file)
 {
@@ -246,7 +240,6 @@ get_file_mime_info (CajaFileInfo *file)
 	return file_mime_info;
 }
 
-
 static gboolean
 unsupported_scheme (CajaFileInfo *file)
 {
@@ -272,7 +265,6 @@ unsupported_scheme (CajaFileInfo *file)
 	return result;
 }
 
-
 static GList *
 caja_fr_get_file_items (CajaMenuProvider *provider,
 			    GtkWidget            *window,
@@ -387,37 +379,31 @@ caja_fr_get_file_items (CajaMenuProvider *provider,
 	return items;
 }
 
-
 static void
 caja_fr_menu_provider_iface_init (CajaMenuProviderIface *iface)
 {
 	iface->get_file_items = caja_fr_get_file_items;
 }
 
-
 static void
 caja_fr_instance_init (CajaFr *fr)
 {
 }
 
-
 static void
 caja_fr_class_init (CajaFrClass *class)
 {
 	parent_class = g_type_class_peek_parent (class);
 }
 
-
 static GType fr_type = 0;
 
-
 GType
 caja_fr_get_type (void)
 {
 	return fr_type;
 }
 
-
 void
 caja_fr_register_type (GTypeModule *module)
 {
