@@ -28,26 +28,23 @@
 #include "preferences.h"
 #include "dlg-password.h"
 
+#define GET_WIDGET(x) (GTK_WIDGET (gtk_builder_get_object (builder, (x))))
 
 typedef struct {
-	GtkBuilder *builder;
 	FrWindow  *window;
 	GtkWidget *dialog;
 	GtkWidget *pw_password_entry;
 	GtkWidget *pw_encrypt_header_checkbutton;
 } DialogData;
 
-
 /* called when the main dialog is closed. */
 static void
 destroy_cb (GtkWidget  *widget,
 	    DialogData *data)
 {
-	g_object_unref (data->builder);
 	g_free (data);
 }
 
-
 static void
 response_cb (GtkWidget  *dialog,
 	     int         response_id,
@@ -79,29 +76,23 @@ response_cb (GtkWidget  *dialog,
 	gtk_widget_destroy (data->dialog);
 }
 
-
 void
 dlg_password (GtkWidget *widget,
 	      gpointer   callback_data)
 {
+	GtkBuilder *builder;
 	FrWindow   *window = callback_data;
 	DialogData *data;
 
 	data = g_new0 (DialogData, 1);
-
-	data->builder = _gtk_builder_new_from_resource ("password.ui");
-	if (data->builder == NULL) {
-		g_free (data);
-		return;
-	}
-
+	builder = gtk_builder_new_from_resource (ENGRAMPA_RESOURCE_UI_PATH G_DIR_SEPARATOR_S "password.ui");
 	data->window = window;
 
 	/* Get the widgets. */
 
-	data->dialog = _gtk_builder_get_widget (data->builder, "password_dialog");
-	data->pw_password_entry = _gtk_builder_get_widget (data->builder, "pw_password_entry");
-	data->pw_encrypt_header_checkbutton = _gtk_builder_get_widget (data->builder, "pw_encrypt_header_checkbutton");
+	data->dialog = GET_WIDGET ("password_dialog");
+	data->pw_password_entry = GET_WIDGET ("pw_password_entry");
+	data->pw_encrypt_header_checkbutton = GET_WIDGET ("pw_encrypt_header_checkbutton");
 
 	/* Set widgets data. */
 
@@ -110,15 +101,13 @@ dlg_password (GtkWidget *widget,
 
 	/* Set the signals handlers. */
 
-	g_signal_connect (G_OBJECT (data->dialog),
-			  "destroy",
-			  G_CALLBACK (destroy_cb),
-			  data);
+	gtk_builder_add_callback_symbols (builder,
+	                                  "on_password_dialog_destroy", G_CALLBACK (destroy_cb),
+	                                  "on_password_dialog_response", G_CALLBACK (response_cb),
+	                                  NULL);
 
-	g_signal_connect (G_OBJECT (data->dialog),
-			  "response",
-			  G_CALLBACK (response_cb),
-			  data);
+	gtk_builder_connect_signals (builder, data);
+	g_object_unref (builder);
 
 	/* Run dialog. */
 
