@@ -24,7 +24,6 @@
  * Boston, MA 02110-1301, USA.
  */
 
-
 #include <string.h>
 #include <gtk/gtk.h>
 #include "eggtreemultidnd.h"
@@ -48,7 +47,6 @@ typedef struct
   gboolean pending_event;
 } EggTreeMultiDndData;
 
-
 GType
 egg_tree_multi_drag_source_get_type (void)
 {
@@ -79,7 +77,6 @@ egg_tree_multi_drag_source_get_type (void)
   return our_type;
 }
 
-
 /**
  * egg_tree_multi_drag_source_row_draggable:
  * @drag_source: a #EggTreeMultiDragSource
@@ -107,7 +104,6 @@ egg_tree_multi_drag_source_row_draggable (EggTreeMultiDragSource *drag_source,
     return TRUE;
 }
 
-
 /**
  * egg_tree_multi_drag_source_drag_data_delete:
  * @drag_source: a #EggTreeMultiDragSource
@@ -134,7 +130,6 @@ egg_tree_multi_drag_source_drag_data_delete (EggTreeMultiDragSource *drag_source
   return (* iface->drag_data_delete) (drag_source, path_list);
 }
 
-
 /**
  * egg_tree_multi_drag_source_drag_data_get:
  * @drag_source: a #EggTreeMultiDragSource
@@ -164,7 +159,6 @@ egg_tree_multi_drag_source_drag_data_get (EggTreeMultiDragSource *drag_source,
   return (* iface->drag_data_get) (drag_source, context, selection_data, path_list);
 }
 
-
 static void
 stop_drag_check (GtkWidget *widget)
 {
@@ -190,7 +184,6 @@ stop_drag_check (GtkWidget *widget)
   }
 }
 
-
 static gboolean
 egg_tree_multi_drag_button_release_event (GtkWidget      *widget,
 					  GdkEventButton *event,
@@ -209,7 +202,6 @@ egg_tree_multi_drag_button_release_event (GtkWidget      *widget,
   return FALSE;
 }
 
-
 static void
 selection_foreach (GtkTreeModel *model,
 		   GtkTreePath  *path,
@@ -223,7 +215,6 @@ selection_foreach (GtkTreeModel *model,
   *list_ptr = g_list_prepend (*list_ptr, gtk_tree_row_reference_new (model, path));
 }
 
-
 static void
 path_list_free (GList *path_list)
 {
@@ -231,7 +222,6 @@ path_list_free (GList *path_list)
   g_list_free (path_list);
 }
 
-
 static void
 set_context_data (GdkDragContext *context,
 		  GList          *path_list)
@@ -242,7 +232,6 @@ set_context_data (GdkDragContext *context,
                           (GDestroyNotify) path_list_free);
 }
 
-
 static GList *
 get_context_data (GdkDragContext *context)
 {
@@ -250,7 +239,6 @@ get_context_data (GdkDragContext *context)
 			    "egg-tree-view-multi-source-row");
 }
 
-
 static gboolean
 egg_tree_multi_drag_drag_data_get (GtkWidget        *widget,
 				   GdkDragContext   *context,
@@ -285,7 +273,6 @@ egg_tree_multi_drag_drag_data_get (GtkWidget        *widget,
 						   path_list);
 }
 
-
 static gboolean
 egg_tree_multi_drag_motion_event (GtkWidget      *widget,
 				  GdkEventMotion *event,
@@ -298,8 +285,8 @@ egg_tree_multi_drag_motion_event (GtkWidget      *widget,
   if (gtk_drag_check_threshold (widget,
 				priv_data->x,
 				priv_data->y,
-				event->x,
-				event->y))
+				(gint) event->x,
+				(gint) event->y))
     {
       GList            *path_list = NULL;
       GtkTreeSelection *selection;
@@ -329,8 +316,8 @@ egg_tree_multi_drag_motion_event (GtkWidget      *widget,
 	                                             GDK_ACTION_COPY,
 	                                             priv_data->pressed_button,
 	                                             (GdkEvent*) event,
-	                                             event->x,
-	                                             event->y);
+	                                             (gint) event->x,
+	                                             (gint) event->y);
 	  set_context_data (context, path_list);
 
 	  if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (widget),
@@ -364,7 +351,6 @@ egg_tree_multi_drag_motion_event (GtkWidget      *widget,
   return TRUE;
 }
 
-
 static gboolean
 egg_tree_multi_drag_button_press_event (GtkWidget      *widget,
 					GdkEventButton *event,
@@ -409,7 +395,7 @@ egg_tree_multi_drag_button_press_event (GtkWidget      *widget,
     return FALSE;
 
   gtk_tree_view_get_path_at_pos (tree_view,
-				 event->x, event->y,
+				 (gint) event->x, (gint) event->y,
 				 &path, &column,
 				 &cell_x, &cell_y);
 
@@ -427,8 +413,8 @@ egg_tree_multi_drag_button_press_event (GtkWidget      *widget,
       if (gtk_tree_selection_path_is_selected (selection, path))
     {
       priv_data->pressed_button = event->button;
-      priv_data->x = event->x;
-      priv_data->y = event->y;
+      priv_data->x = (gint) event->x;
+      priv_data->y = (gint) event->y;
 
       priv_data->pending_event = TRUE;
       if (!call_parent)
@@ -471,7 +457,6 @@ egg_tree_multi_drag_button_press_event (GtkWidget      *widget,
   return FALSE;
 }
 
-
 void
 egg_tree_multi_drag_add_drag_support (GtkTreeView *tree_view)
 {
