@@ -40,10 +40,8 @@ static void fr_command_ace_finalize    (GObject          *object);
 
 static FrCommandClass *parent_class = NULL;
 
-
 /* -- list -- */
 
-
 static time_t
 mktime_from_string (char *date,
 		    char *time)
@@ -85,7 +83,6 @@ mktime_from_string (char *date,
 	return mktime (&tm);
 }
 
-
 static void
 process_line (char     *line,
 	      gpointer  data)
@@ -164,7 +161,6 @@ process_line (char     *line,
 		fr_command_add_file (comm, fdata);
 }
 
-
 static void
 list__begin (gpointer data)
 {
@@ -174,7 +170,6 @@ list__begin (gpointer data)
 	comm->command_type = FR_ACE_COMMAND_UNKNOWN;
 }
 
-
 static void
 fr_command_ace_list (FrCommand  *comm)
 {
@@ -189,7 +184,6 @@ fr_command_ace_list (FrCommand  *comm)
 	fr_process_start (comm->process);
 }
 
-
 static void
 fr_command_ace_extract (FrCommand   *comm,
 			const char  *from_file,
@@ -219,7 +213,6 @@ fr_command_ace_extract (FrCommand   *comm,
 	fr_process_end_command (comm->process);
 }
 
-
 static void
 fr_command_ace_test (FrCommand   *comm)
 {
@@ -230,7 +223,6 @@ fr_command_ace_test (FrCommand   *comm)
         fr_process_end_command (comm->process);
 }
 
-
 static void
 fr_command_ace_handle_error (FrCommand   *comm,
 			     FrProcError *error)
@@ -238,23 +230,20 @@ fr_command_ace_handle_error (FrCommand   *comm,
 	/* FIXME */
 }
 
-
 const char *ace_mime_type[] = { "application/x-ace", NULL };
 
-
 static const char **
 fr_command_ace_get_mime_types (FrCommand *comm)
 {
 	return ace_mime_type;
 }
 
-
-static FrCommandCap
+static FrCommandCaps
 fr_command_ace_get_capabilities (FrCommand  *comm,
 			         const char *mime_type,
 				 gboolean    check_command)
 {
-	FrCommandCap capabilities;
+	FrCommandCaps capabilities;
 
 	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES;
 	if (is_program_available ("unace", check_command))
@@ -263,7 +252,6 @@ fr_command_ace_get_capabilities (FrCommand  *comm,
 	return capabilities;
 }
 
-
 static const char *
 fr_command_ace_get_packages (FrCommand  *comm,
 			     const char *mime_type)
@@ -271,7 +259,6 @@ fr_command_ace_get_packages (FrCommand  *comm,
 	return PACKAGES ("unace");
 }
 
-
 static void
 fr_command_ace_class_init (FrCommandAceClass *class)
 {
@@ -292,7 +279,6 @@ fr_command_ace_class_init (FrCommandAceClass *class)
 	afc->get_packages     = fr_command_ace_get_packages;
 }
 
-
 static void
 fr_command_ace_init (FrCommand *comm)
 {
@@ -305,7 +291,6 @@ fr_command_ace_init (FrCommand *comm)
 	comm->propTest                     = TRUE;
 }
 
-
 static void
 fr_command_ace_finalize (GObject *object)
 {
@@ -317,7 +302,6 @@ fr_command_ace_finalize (GObject *object)
 		G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-
 GType
 fr_command_ace_get_type ()
 {
