@@ -41,7 +41,6 @@ static void fr_command_cpio_finalize    (GObject           *object);
 
 static FrCommandClass *parent_class = NULL;
 
-
 /* -- list -- */
 
 static time_t
@@ -85,7 +84,6 @@ mktime_from_string (char *month,
 	return mktime (&tm);
 }
 
-
 static void
 list__process_line (char     *line,
 		    gpointer  data)
@@ -170,7 +168,6 @@ list__process_line (char     *line,
 		fr_command_add_file (comm, fdata);
 }
 
-
 static void
 fr_command_cpio_list (FrCommand  *comm)
 {
@@ -183,7 +180,6 @@ fr_command_cpio_list (FrCommand  *comm)
 	fr_process_start (comm->process);
 }
 
-
 static void
 fr_command_cpio_extract (FrCommand *comm,
 			const char *from_file,
@@ -223,23 +219,20 @@ fr_command_cpio_extract (FrCommand *comm,
 	fr_process_end_command (comm->process);
 }
 
-
 const char *cpio_mime_type[] = { /*"application/x-cpio",*/ NULL };
 
-
 static const char **
 fr_command_cpio_get_mime_types (FrCommand *comm)
 {
 	return cpio_mime_type;
 }
 
-
-static FrCommandCap
+static FrCommandCaps
 fr_command_cpio_get_capabilities (FrCommand  *comm,
 			          const char *mime_type,
 				  gboolean    check_command)
 {
-	FrCommandCap capabilities;
+	FrCommandCaps capabilities;
 
 	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES;
 /*	if (is_program_available (CPIO_PATH, check_command))
@@ -248,7 +241,6 @@ fr_command_cpio_get_capabilities (FrCommand  *comm,
 	return capabilities;
 }
 
-
 static const char *
 fr_command_cpio_get_packages (FrCommand  *comm,
 			      const char *mime_type)
@@ -256,7 +248,6 @@ fr_command_cpio_get_packages (FrCommand  *comm,
 	return PACKAGES ("cpio");
 }
 
-
 static void
 fr_command_cpio_class_init (FrCommandCpioClass *class)
 {
@@ -275,7 +266,6 @@ fr_command_cpio_class_init (FrCommandCpioClass *class)
 	afc->get_packages     = fr_command_cpio_get_packages;
 }
 
-
 static void
 fr_command_cpio_init (FrCommand *comm)
 {
@@ -289,7 +279,6 @@ fr_command_cpio_init (FrCommand *comm)
 	comm->propTest                     = FALSE;
 }
 
-
 static void
 fr_command_cpio_finalize (GObject *object)
 {
@@ -301,7 +290,6 @@ fr_command_cpio_finalize (GObject *object)
 		G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-
 GType
 fr_command_cpio_get_type ()
 {
