@@ -41,7 +41,6 @@ static void fr_command_iso_finalize    (GObject           *object);
 
 static FrCommandClass *parent_class = NULL;
 
-
 static time_t
 mktime_from_string (char *month,
 		    char *mday,
@@ -69,7 +68,6 @@ mktime_from_string (char *month,
 	return mktime (&tm);
 }
 
-
 static void
 list__process_line (char     *line,
 		    gpointer  data)
@@ -128,7 +126,6 @@ list__process_line (char     *line,
 	}
 }
 
-
 static void
 list__begin (gpointer data)
 {
@@ -138,7 +135,6 @@ list__begin (gpointer data)
 	comm->cur_path = NULL;
 }
 
-
 static void
 fr_command_iso_list (FrCommand *comm)
 {
@@ -155,7 +151,6 @@ fr_command_iso_list (FrCommand *comm)
 	fr_process_start (comm->process);
 }
 
-
 static void
 fr_command_iso_extract (FrCommand  *comm,
 			const char *from_file,
@@ -200,23 +195,20 @@ fr_command_iso_extract (FrCommand  *comm,
 	}
 }
 
-
 const char *iso_mime_type[] = { "application/x-cd-image", NULL };
 
-
 static const char **
 fr_command_iso_get_mime_types (FrCommand *comm)
 {
 	return iso_mime_type;
 }
 
-
-static FrCommandCap
+static FrCommandCaps
 fr_command_iso_get_capabilities (FrCommand  *comm,
 			         const char *mime_type,
 				 gboolean    check_command)
 {
-	FrCommandCap capabilities;
+	FrCommandCaps capabilities;
 
 	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES;
 	if (is_program_available ("isoinfo", check_command))
@@ -225,7 +217,6 @@ fr_command_iso_get_capabilities (FrCommand  *comm,
 	return capabilities;
 }
 
-
 static const char *
 fr_command_iso_get_packages (FrCommand  *comm,
 			     const char *mime_type)
@@ -233,7 +224,6 @@ fr_command_iso_get_packages (FrCommand  *comm,
 	return PACKAGES ("genisoimage");
 }
 
-
 static void
 fr_command_iso_class_init (FrCommandIsoClass *class)
 {
@@ -252,7 +242,6 @@ fr_command_iso_class_init (FrCommandIsoClass *class)
 	afc->get_packages     = fr_command_iso_get_packages;
 }
 
-
 static void
 fr_command_iso_init (FrCommand *comm)
 {
@@ -271,7 +260,6 @@ fr_command_iso_init (FrCommand *comm)
 	comm->propCanExtractAll            = FALSE;
 }
 
-
 static void
 fr_command_iso_finalize (GObject *object)
 {
@@ -290,7 +278,6 @@ fr_command_iso_finalize (GObject *object)
 		G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-
 GType
 fr_command_iso_get_type ()
 {
