@@ -50,7 +50,6 @@ static void fr_command_tar_finalize    (GObject           *object);
 
 static FrCommandClass *parent_class = NULL;
 
-
 /* -- list -- */
 
 static time_t
@@ -62,7 +61,6 @@ mktime_from_string (const char *time_s)
 	return mktime (&tm);
 }
 
-
 static char*
 tar_get_last_field (const char *line,
 		    int         start_from,
@@ -92,7 +90,6 @@ tar_get_last_field (const char *line,
 	return g_strdup (f_start);
 }
 
-
 static void
 process_line (char     *line,
 	      gpointer  data)
@@ -164,7 +161,6 @@ process_line (char     *line,
 		fr_command_add_file (comm, fdata);
 }
 
-
 static void
 add_compress_arg (FrCommand *comm)
 {
@@ -214,7 +210,6 @@ add_compress_arg (FrCommand *comm)
 	}
 }
 
-
 static void
 begin_tar_command (FrCommand *comm)
 {
@@ -236,7 +231,6 @@ begin_tar_command (FrCommand *comm)
 	g_free (command);
 }
 
-
 static void
 fr_command_tar_list (FrCommand *comm)
 {
@@ -252,14 +246,12 @@ fr_command_tar_list (FrCommand *comm)
 	fr_process_start (comm->process);
 }
 
-
 static gboolean
 can_create_a_compressed_archive (FrCommand *comm)
 {
 	return comm->creating_archive && ! is_mime_type (comm->mime_type, "application/x-7z-compressed-tar");
 }
 
-
 static void
 process_line__generic (char     *line,
 		       gpointer  data,
@@ -284,7 +276,6 @@ process_line__generic (char     *line,
 	}
 }
 
-
 static void
 process_line__add (char     *line,
 		   gpointer  data)
@@ -293,7 +284,6 @@ process_line__add (char     *line,
 	process_line__generic (line, data, _("Adding file: "));
 }
 
-
 static void
 fr_command_tar_add (FrCommand     *comm,
 		    const char    *from_file,
@@ -350,7 +340,6 @@ fr_command_tar_add (FrCommand     *comm,
 	fr_process_end_command (comm->process);
 }
 
-
 static void
 process_line__delete (char     *line,
 		      gpointer  data)
@@ -359,7 +348,6 @@ process_line__delete (char     *line,
 	process_line__generic (line, data, _("Removing file: "));
 }
 
-
 static void
 begin_func__delete (gpointer data)
 {
@@ -368,7 +356,6 @@ begin_func__delete (gpointer data)
 	fr_command_message (comm, _("Deleting files from archive"));
 }
 
-
 static void
 fr_command_tar_delete (FrCommand  *comm,
 		       const char *from_file,
@@ -405,7 +392,6 @@ fr_command_tar_delete (FrCommand  *comm,
 	fr_process_end_command (comm->process);
 }
 
-
 static void
 process_line__extract (char     *line,
 		       gpointer  data)
@@ -414,7 +400,6 @@ process_line__extract (char     *line,
 	process_line__generic (line, data, _("Extracting file: "));
 }
 
-
 static void
 fr_command_tar_extract (FrCommand  *comm,
 		        const char *from_file,
@@ -465,7 +450,6 @@ fr_command_tar_extract (FrCommand  *comm,
 	fr_process_end_command (comm->process);
 }
 
-
 static void
 begin_func__recompress (gpointer data)
 {
@@ -474,7 +458,6 @@ begin_func__recompress (gpointer data)
 	fr_command_message (comm, _("Recompressing archive"));
 }
 
-
 static gboolean
 gzip_continue_func (gpointer user_data)
 {
@@ -491,7 +474,6 @@ gzip_continue_func (gpointer user_data)
 	return comm->process->error.status == 0;
 }
 
-
 static void
 fr_command_tar_recompress (FrCommand *comm)
 {
@@ -682,7 +664,8 @@ fr_command_tar_recompress (FrCommand *comm)
 		fr_process_add_arg (comm->process, "a");
 		fr_process_add_arg (comm->process, "-bd");
 		fr_process_add_arg (comm->process, "-y");
-		fr_process_add_arg (comm->process, "-l");
+		if (g_strcmp0 (comm_tar->compress_command, "7zzs") != 0 && g_strcmp0 (comm_tar->compress_command, "7zz") != 0)
+			fr_process_add_arg (comm->process, "-l");
 
 		new_name = g_strconcat (c_tar->uncomp_filename, ".7z", NULL);
 		fr_process_add_arg_concat (comm->process, new_name, NULL);
@@ -725,7 +708,6 @@ fr_command_tar_recompress (FrCommand *comm)
 	c_tar->uncomp_filename = NULL;
 }
 
-
 static void
 begin_func__uncompress (gpointer data)
 {
@@ -734,7 +716,6 @@ begin_func__uncompress (gpointer data)
 	fr_command_message (comm, _("Decompressing archive"));
 }
 
-
 static char *
 get_uncompressed_name (FrCommandTar *c_tar,
 		       const char   *e_filename)
@@ -838,7 +819,6 @@ get_uncompressed_name (FrCommandTar *c_tar,
 	return new_name;
 }
 
-
 static char *
 get_temp_name (FrCommandTar *c_tar,
 	       const char   *filepath)
@@ -856,7 +836,6 @@ get_temp_name (FrCommandTar *c_tar,
 	return temp_name;
 }
 
-
 static void
 fr_command_tar_uncompress (FrCommand *comm)
 {
@@ -998,7 +977,6 @@ fr_command_tar_uncompress (FrCommand *comm)
 	g_free (tmp_name);
 }
 
-
 static void
 fr_command_tar_handle_error (FrCommand   *comm,
 			     FrProcError *error)
@@ -1009,7 +987,6 @@ fr_command_tar_handle_error (FrCommand   *comm,
 	}
 }
 
-
 const char *tar_mime_types[] = { "application/x-compressed-tar",
 				 "application/x-brotli-compressed-tar",
 				 "application/x-bzip-compressed-tar",
@@ -1024,20 +1001,18 @@ const char *tar_mime_types[] = { "application/x-compressed-tar",
 				 "application/x-zstd-compressed-tar",
 			         NULL };
 
-
 static const char **
 fr_command_tar_get_mime_types (FrCommand *comm)
 {
 	return tar_mime_types;
 }
 
-
-static FrCommandCap
+static FrCommandCaps
 fr_command_tar_get_capabilities (FrCommand  *comm,
 			         const char *mime_type,
 				 gboolean    check_command)
 {
-	FrCommandCap capabilities;
+	FrCommandCaps capabilities;
 
 	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES;
 
@@ -1087,7 +1062,7 @@ fr_command_tar_get_capabilities (FrCommand  *comm,
 			capabilities |= FR_COMMAND_CAN_READ_WRITE;
 	}
 	else if (is_mime_type (mime_type, "application/x-7z-compressed-tar")) {
-		const char *try_command[3] = { "7za", "7zr", "7z" };
+		const char *try_command[5] = { "7zzs", "7zz", "7za", "7zr", "7z" };
 		size_t i;
 
 		for (i = 0; i < G_N_ELEMENTS (try_command); i++) {
@@ -1105,7 +1080,6 @@ fr_command_tar_get_capabilities (FrCommand  *comm,
 	return capabilities;
 }
 
-
 static void
 fr_command_tar_set_mime_type (FrCommand  *comm,
 		 	      const char *mime_type)
@@ -1115,7 +1089,7 @@ fr_command_tar_set_mime_type (FrCommand  *comm,
 	FR_COMMAND_CLASS (parent_class)->set_mime_type (comm, mime_type);
 
 	if (is_mime_type (mime_type, "application/x-7z-compressed-tar")) {
-		const char *try_command[3] = { "7za", "7zr", "7z" };
+		const char *try_command[5] = { "7zzs", "7zz", "7za", "7zr", "7z" };
 		size_t i;
 
 		for (i = 0; i < G_N_ELEMENTS (try_command); i++) {
@@ -1127,7 +1101,6 @@ fr_command_tar_set_mime_type (FrCommand  *comm,
 	}
 }
 
-
 static const char *
 fr_command_tar_get_packages (FrCommand  *comm,
 			     const char *mime_type)
@@ -1153,14 +1126,13 @@ fr_command_tar_get_packages (FrCommand  *comm,
 	else if (is_mime_type (mime_type, "application/x-lzop-compressed-tar"))
 		return PACKAGES ("tar,lzop");
 	else if (is_mime_type (mime_type, "application/x-7z-compressed-tar"))
-		return PACKAGES ("tar,p7zip");
+		return PACKAGES ("tar,7zip");
 	else if (is_mime_type (mime_type, "application/x-zstd-compressed-tar"))
 		return PACKAGES ("tar,zstd");
 
 	return NULL;
 }
 
-
 static void
 fr_command_tar_class_init (FrCommandTarClass *class)
 {
@@ -1185,7 +1157,6 @@ fr_command_tar_class_init (FrCommandTarClass *class)
 	afc->get_packages     = fr_command_tar_get_packages;
 }
 
-
 static void
 fr_command_tar_init (FrCommand *comm)
 {
@@ -1207,7 +1178,6 @@ fr_command_tar_init (FrCommand *comm)
 	comm_tar->uncomp_filename = NULL;
 }
 
-
 static void
 fr_command_tar_finalize (GObject *object)
 {
@@ -1238,7 +1208,6 @@ fr_command_tar_finalize (GObject *object)
 		G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-
 GType
 fr_command_tar_get_type ()
 {
