@@ -40,7 +40,6 @@ static void fr_command_zoo_finalize    (GObject           *object);
 
 static FrCommandClass *parent_class = NULL;
 
-
 /* -- list -- */
 
 static time_t
@@ -106,7 +105,6 @@ mktime_from_string_zoo (char *mday_s,
 	return mktime (&tm);
 }
 
-
 static char **
 split_line_zoo (char *line)
 {
@@ -147,7 +145,6 @@ split_line_zoo (char *line)
 	return fields;
 }
 
-
 static const char *
 get_last_field_zoo (char *line)
 {
@@ -171,7 +168,6 @@ get_last_field_zoo (char *line)
 	return field;
 }
 
-
 static void
 process_zoo_line (char     *line,
 		  gpointer  data)
@@ -218,7 +214,6 @@ process_zoo_line (char     *line,
 		fr_command_add_file (zoo_comm, fdata);
 }
 
-
 static void
 fr_command_zoo_list (FrCommand  *zoo_comm)
 {
@@ -231,7 +226,6 @@ fr_command_zoo_list (FrCommand  *zoo_comm)
 	fr_process_start (zoo_comm->process);
 }
 
-
 static void
 fr_command_zoo_add (FrCommand     *comm,
 		    const char    *from_file,
@@ -260,7 +254,6 @@ fr_command_zoo_add (FrCommand     *comm,
 	fr_process_end_command (comm->process);
 }
 
-
 static void
 fr_command_zoo_delete (FrCommand *comm,
 		       const char  *from_file,
@@ -279,7 +272,6 @@ fr_command_zoo_delete (FrCommand *comm,
 	fr_process_end_command (comm->process);
 }
 
-
 static void
 fr_command_zoo_extract (FrCommand  *comm,
 			const char  *from_file,
@@ -309,7 +301,6 @@ fr_command_zoo_extract (FrCommand  *comm,
 	fr_process_end_command (comm->process);
 }
 
-
 static void
 fr_command_zoo_test (FrCommand   *comm)
 {
@@ -319,23 +310,20 @@ fr_command_zoo_test (FrCommand   *comm)
 	fr_process_end_command (comm->process);
 }
 
-
 const char *zoo_mime_type[] = { "application/x-zoo", NULL };
 
-
 static const char **
 fr_command_zoo_get_mime_types (FrCommand *comm)
 {
 	return zoo_mime_type;
 }
 
-
-static FrCommandCap
+static FrCommandCaps
 fr_command_zoo_get_capabilities (FrCommand  *comm,
 			         const char *mime_type,
 				 gboolean    check_command)
 {
-	FrCommandCap capabilities;
+	FrCommandCaps capabilities;
 
 	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES;
 	if (is_program_available ("zoo", check_command))
@@ -344,7 +332,6 @@ fr_command_zoo_get_capabilities (FrCommand  *comm,
 	return capabilities;
 }
 
-
 static const char *
 fr_command_zoo_get_packages (FrCommand  *comm,
 			     const char *mime_type)
@@ -352,7 +339,6 @@ fr_command_zoo_get_packages (FrCommand  *comm,
 	return PACKAGES ("zoo");
 }
 
-
 static void
 fr_command_zoo_class_init (FrCommandZooClass *class)
 {
@@ -374,7 +360,6 @@ fr_command_zoo_class_init (FrCommandZooClass *class)
 	afc->get_packages     = fr_command_zoo_get_packages;
 }
 
-
 static void
 fr_command_zoo_init (FrCommand *comm)
 {
@@ -387,7 +372,6 @@ fr_command_zoo_init (FrCommand *comm)
 	comm->propTest                     = TRUE;
 }
 
-
 static void
 fr_command_zoo_finalize (GObject *object)
 {
@@ -399,7 +383,6 @@ fr_command_zoo_finalize (GObject *object)
 		G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-
 GType
 fr_command_zoo_get_type ()
 {
