@@ -60,7 +60,7 @@ typedef enum {
 	FR_ACTION_SAVING_REMOTE_ARCHIVE       /* copying the archive to a remote location */
 } FrAction;
 
-#if MATE_ENABLE_DEBUG
+#ifdef MATE_ENABLE_DEBUG
 const char * get_action_name (FrAction action);
 #endif
 
@@ -146,7 +146,7 @@ struct _FrCommandClass
 	void          (*handle_error)     (FrCommand     *comm,
 				           FrProcError   *error);
 	const char ** (*get_mime_types)   (FrCommand     *comm);
-	FrCommandCap  (*get_capabilities) (FrCommand     *comm,
+	FrCommandCaps (*get_capabilities) (FrCommand     *comm,
 					   const char    *mime_type,
 					   gboolean       check_command);
 	void          (*set_mime_type)    (FrCommand     *comm,
@@ -198,7 +198,7 @@ gboolean       fr_command_is_capable_of       (FrCommand     *comm,
 					       FrCommandCaps  capabilities);
 const char **  fr_command_get_mime_types      (FrCommand     *comm);
 void           fr_command_update_capabilities (FrCommand     *comm);
-FrCommandCap   fr_command_get_capabilities    (FrCommand     *comm,
+FrCommandCaps  fr_command_get_capabilities    (FrCommand     *comm,
 					       const char    *mime_type,
 					       gboolean       check_command);
 void           fr_command_set_mime_type       (FrCommand     *comm,
