@@ -28,7 +28,6 @@
 #include "typedefs.h"
 #include "fr-archive.h"
 
-
 enum {
 	COLUMN_FILE_DATA,
 	COLUMN_ICON,
@@ -54,6 +53,7 @@ typedef enum {
 	FR_BATCH_ACTION_LOAD,
 	FR_BATCH_ACTION_OPEN,
 	FR_BATCH_ACTION_ADD,
+	FR_BATCH_ACTION_DELETE,
 	FR_BATCH_ACTION_EXTRACT,
 	FR_BATCH_ACTION_EXTRACT_HERE,
 	FR_BATCH_ACTION_EXTRACT_INTERACT,
@@ -152,6 +152,7 @@ void        fr_window_archive_remove            (FrWindow      *window,
 void        fr_window_archive_extract           (FrWindow      *window,
 						 GList         *file_list,
 						 const char    *extract_to_dir,
+						 const char    *sub_dir,
 						 const char    *base_dir,
 						 gboolean       skip_older,
 						 FrOverwrite    overwrite,
@@ -159,7 +160,7 @@ void        fr_window_archive_extract           (FrWindow      *window,
 						 gboolean       ask_to_open_destination);
 void        fr_window_archive_extract_here      (FrWindow      *window,
 						 gboolean       skip_older,
-						 gboolean       overwrite,
+						 FrOverwrite    overwrite,
 						 gboolean       junk_paths);
 void        fr_window_archive_test	        (FrWindow      *window);
 
@@ -217,9 +218,6 @@ GtkTreeModel *
 void       fr_window_find                         (FrWindow    *window);
 void       fr_window_select_all                   (FrWindow    *window);
 void       fr_window_unselect_all                 (FrWindow    *window);
-void       fr_window_set_sort_type                (FrWindow    *window,
-						   GtkSortType  sort_type);
-
 /**/
 
 void       fr_window_rename_selection             (FrWindow    *window,
@@ -317,4 +315,6 @@ gboolean   fr_window_file_list_drag_data_get (FrWindow         *window,
 
 void       fr_window_update_dialog_closed    (FrWindow *window);
 
+void       fr_window_set_close_dialog        (FrWindow *window,
+				               gboolean  state);
 #endif /* FR_WINDOW_H */
