@@ -89,7 +89,7 @@ static const GOptionEntry options[] = {
 	  NULL,
 	  NULL },
 
-	{ NULL }
+	{ NULL, 0, 0, G_OPTION_ARG_NONE, NULL, NULL, NULL }
 };
 
 static void
@@ -236,7 +236,6 @@ prepare_app (void)
 	g_free (extract_to_uri);
 }
 
-
 static void
 startup_cb (GApplication *application)
 {
@@ -244,7 +243,6 @@ startup_cb (GApplication *application)
 	prepare_app ();
 }
 
-
 static void
 activate_cb (GApplication *application)
 {
@@ -259,7 +257,6 @@ activate_cb (GApplication *application)
 	}
 }
 
-
 static void
 fr_save_state (EggSMClient *client, GKeyFile *state, gpointer user_data)
 {
@@ -287,7 +284,7 @@ fr_save_state (EggSMClient *client, GKeyFile *state, gpointer user_data)
 			FrWindow *session = window->data;
 			gchar *key;
 
-			key = g_strdup_printf ("archive%d", i);
+			key = g_strdup_printf ("archive%d", i+1);
 			if ((session->archive == NULL) || (session->archive->file == NULL)) {
 				g_key_file_set_string (state, "Session", key, "");
 			}
@@ -305,7 +302,6 @@ fr_save_state (EggSMClient *client, GKeyFile *state, gpointer user_data)
 	g_key_file_set_integer (state, "Session", "archives", i);
 }
 
-
 int
 main (int argc, char **argv)
 {
