@@ -27,11 +27,9 @@
 #include "file-utils.h"
 #include "fr-init.h"
 
-
 #define FR_SERVICE_NAME "org.mate.Engrampa"
 #define FR_SERVICE_PATH "/org/mate/Engrampa"
 
-
 static const char introspection_xml[] =
 	"<node>"
 	"  <interface name='org.mate.ArchiveManager'>"
@@ -173,7 +171,6 @@ static const char introspection_xml[] =
 
 static GDBusNodeInfo *introspection_data = NULL;
 
-
 static void
 window_ready_cb (GtkWidget *widget,
 		 GError    *error,
@@ -189,7 +186,6 @@ window_ready_cb (GtkWidget *widget,
 						       error->message);
 }
 
-
 static gboolean
 window_progress_cb (FrWindow *window,
 		    double    fraction,
@@ -211,7 +207,6 @@ window_progress_cb (FrWindow *window,
 	return TRUE;
 }
 
-
 static void
 handle_method_call (GDBusConnection       *connection,
 		    const char            *sender,
@@ -385,14 +380,13 @@ handle_method_call (GDBusConnection       *connection,
 	}
 }
 
-
 static const GDBusInterfaceVTable interface_vtable = {
 	handle_method_call,
 	NULL, 			/* handle_get_property */
-	NULL 			/* handle_set_property */
+	NULL, 			/* handle_set_property */
+	{ 0 }
 };
 
-
 static void
 on_bus_acquired (GDBusConnection *connection,
 		 const char      *name,
@@ -412,7 +406,6 @@ on_bus_acquired (GDBusConnection *connection,
 	initialize_data ();
 }
 
-
 static void
 on_name_acquired (GDBusConnection *connection,
 		  const char      *name,
@@ -420,7 +413,6 @@ on_name_acquired (GDBusConnection *connection,
 {
 }
 
-
 static void
 on_name_lost (GDBusConnection *connection,
 	      const char      *name,
@@ -429,7 +421,6 @@ on_name_lost (GDBusConnection *connection,
 	gtk_main_quit ();
 }
 
-
 int
 main (int argc, char *argv[])
 {
